"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const highlight_js_1 = __importDefault(require("highlight.js"));
function createHighlightPlugin(config = {}) {
    return function highlightPlugin(tree) {
        const highlightCodeTags = (node) => tree.match.call(node, { tag: 'code' }, highlightNode);
        highlight_js_1.default.configure(config);
        if (config.inline) {
            highlightCodeTags(tree);
        }
        else {
            tree.match({ tag: 'pre' }, highlightCodeTags);
        }
    };
}
exports.default = createHighlightPlugin;
function highlightNode(node) {
    const attrs = node.attrs || {};
    const classList = `${attrs.class || ''} hljs`.trimLeft();
    if (classList.includes('nohighlight'))
        return node;
    const lang = getExplicitLanguage(classList);
    attrs.class = classList;
    node.attrs = attrs;
    if (node.content) {
        node.content = node.content.map((c) => mapContentOrNode(c, lang));
    }
    return node;
}
function getExplicitLanguage(classList) {
    const matches = /(?:lang|language)-(\w*)/.exec(classList);
    return matches === null ? void 0 : matches[1];
}
function mapContentOrNode(contentOrNode, lang) {
    if (typeof contentOrNode === 'string') {
        if (lang) {
            return highlight_js_1.default.highlight(contentOrNode, { language: lang }).value;
        }
        else {
            return highlight_js_1.default.highlightAuto(contentOrNode).value;
        }
    }
    else {
        highlightNode(contentOrNode);
        return contentOrNode;
    }
}
